@@ -106,6 +106,8 @@ static forceinline char *h1c_show_flags(char *buf, size_t len, const char *delim
 #define H1S_F_HAVE_CLEN      0x00010000 /* Set during output process to know C*L header was found or generated */
 #define H1S_F_HAVE_CHNK      0x00020000 /* Set during output process to know "T-E; chunk" header was found or generated */
 
+#define H1S_F_BODYLESS_REQ   0x00040000 /* Bodyless request message */
+
 /* This function is used to report flags in debugging tools. Please reflect
  * below any single-bit flag addition above in the same order via the
  * __APPEND_FLAG macro. The new end of the buffer is returned.
@@ -121,7 +123,7 @@ static forceinline char *h1s_show_flags(char *buf, size_t len, const char *delim
 	_(H1S_F_NOT_FIRST, _(H1S_F_BODYLESS_RESP,
 	_(H1S_F_INTERNAL_ERROR, _(H1S_F_NOT_IMPL_ERROR, _(H1S_F_PARSING_ERROR, _(H1S_F_PROCESSING_ERROR,
 	_(H1S_F_HAVE_SRV_NAME, _(H1S_F_HAVE_O_CONN, _(H1S_F_HAVE_WS_KEY,
-	_(H1S_F_HAVE_CLEN, _(H1S_F_HAVE_CHNK)))))))))))))))));
+	_(H1S_F_HAVE_CLEN, _(H1S_F_HAVE_CHNK, _(H1S_F_BODYLESS_REQ))))))))))))))))));
 	/* epilogue */
 	_(~0U);
 	return buf;
@@ -134,6 +136,7 @@ enum h1_cs {
 	H1_CS_EMBRYONIC,   /* Connection is waiting for the message headers (H1S is not NULL, not attached to a SC - Frontend connection only) */
 	H1_CS_UPGRADING,   /* TCP>H1 upgrade in-progress (H1S is not NULL and attached to a SC - Frontend connection only) */
 	H1_CS_RUNNING,     /* Connection fully established and the H1S is processing data (H1S is not NULL and attached to a SC) */
+	H1_CS_DRAINING,    /* H1C is draining the message before destroying the H1S (H1S is not NULL but no SC attached) */
 	H1_CS_CLOSING,     /* Send pending outgoing data and close the connection ASAP  (H1S may be NULL) */
 	H1_CS_CLOSED,      /* Connection must be closed now and H1C must be released (H1S is NULL) */
 	H1_CS_ENTRIES,
@@ -150,6 +153,7 @@ static inline const char *h1c_st_to_str(enum h1_cs st)
 	case H1_CS_EMBRYONIC: return "EMB";
 	case H1_CS_UPGRADING: return "UPG";
 	case H1_CS_RUNNING:   return "RUN";
+	case H1_CS_DRAINING:  return "DRN";
 	case H1_CS_CLOSING:   return "CLI";
 	case H1_CS_CLOSED:    return "CLD";
 	default:              return "???";
