@@ -324,8 +324,8 @@ static int mux_pt_init(struct connection *conn, struct proxy *prx, struct sessio
 	}
 	conn->ctx = ctx;
 	se_fl_set(ctx->sd, SE_FL_RCV_MORE);
-	if (global.tune.options & GTUNE_USE_SPLICE)
-		se_fl_set(ctx->sd, SE_FL_MAY_FASTFWD);
+	if ((global.tune.options & GTUNE_USE_SPLICE) && !(global.tune.no_zero_copy_fwd & NO_ZERO_COPY_FWD_PT))
+		se_fl_set(ctx->sd, SE_FL_MAY_FASTFWD_PROD|SE_FL_MAY_FASTFWD_CONS);
 
 	TRACE_LEAVE(PT_EV_CONN_NEW, conn);
 	return 0;
@@ -391,6 +391,8 @@ static int mux_pt_attach(struct connection *conn, struct sedesc *sd, struct sess
 		return -1;
 	ctx->sd = sd;
 	se_fl_set(ctx->sd, SE_FL_RCV_MORE);
+	if ((global.tune.options & GTUNE_USE_SPLICE) && !(global.tune.no_zero_copy_fwd & NO_ZERO_COPY_FWD_PT))
+		se_fl_set(ctx->sd, SE_FL_MAY_FASTFWD_PROD|SE_FL_MAY_FASTFWD_CONS);
 
 	TRACE_LEAVE(PT_EV_STRM_NEW, conn, sd->sc);
 	return 0;
@@ -655,11 +657,6 @@ static int mux_pt_fastfwd(struct stconn *sc, unsigned int count, unsigned int fl
 
 	TRACE_ENTER(PT_EV_RX_DATA, conn, sc, 0, (size_t[]){count});
 
-	if (global.tune.no_zero_copy_fwd & NO_ZERO_COPY_FWD_PT) {
-		se_fl_clr(ctx->sd, SE_FL_MAY_FASTFWD);
-		goto end;
-	}
-
 	se_fl_clr(ctx->sd, SE_FL_RCV_MORE | SE_FL_WANT_ROOM);
 	conn->flags &= ~CO_FL_WAIT_ROOM;
 	sdo = mux_pt_opposite_sd(ctx);
@@ -671,7 +668,7 @@ static int mux_pt_fastfwd(struct stconn *sc, unsigned int count, unsigned int fl
 	try = se_nego_ff(sdo, &BUF_NULL, count, conn->xprt->rcv_pipe && !!(flags & CO_RFL_MAY_SPLICE) && !(sdo->iobuf.flags & IOBUF_FL_NO_SPLICING));
 	if (sdo->iobuf.flags & IOBUF_FL_NO_FF) {
 		/* Fast forwarding is not supported by the consumer */
-		se_fl_clr(ctx->sd, SE_FL_MAY_FASTFWD);
+		se_fl_clr(ctx->sd, SE_FL_MAY_FASTFWD_PROD);
 		TRACE_DEVEL("Fast-forwarding not supported by opposite endpoint, disable it", PT_EV_RX_DATA, conn, sc);
 		goto end;
 	}
@@ -689,7 +686,7 @@ static int mux_pt_fastfwd(struct stconn *sc, unsigned int count, unsigned int fl
 		if (ret < 0) {
 			TRACE_ERROR("Error when trying to fast-forward data, disable it and abort",
 				    PT_EV_RX_DATA|PT_EV_STRM_ERR|PT_EV_CONN_ERR, conn, sc);
-			se_fl_clr(ctx->sd, SE_FL_MAY_FASTFWD);
+			se_fl_clr(ctx->sd, SE_FL_MAY_FASTFWD_PROD);
 			BUG_ON(sdo->iobuf.pipe->data);
 			put_pipe(sdo->iobuf.pipe);
 			sdo->iobuf.pipe = NULL;
