@@ -316,7 +316,7 @@ void mworker_broadcast_signal(struct sig_handler *sh)
  */
 void mworker_catch_sighup(struct sig_handler *sh)
 {
-	mworker_reload();
+	mworker_reload(0);
 }
 
 void mworker_catch_sigterm(struct sig_handler *sh)
@@ -385,10 +385,15 @@ restart_wait:
 				else if (child->options & PROC_O_TYPE_PROG)
 					ha_alert("Current program '%s' (%d) exited with code %d (%s)\n", child->id, exitpid, status, (status >= 128) ? strsignal(status - 128) : "Exit");
 
-				if (status != 0 && status != 130 && status != 143
-				    && !(global.tune.options & GTUNE_NOEXIT_ONFAILURE)) {
-					ha_alert("exit-on-failure: killing every processes with SIGTERM\n");
-					mworker_kill(SIGTERM);
+				if (status != 0 && status != 130 && status != 143) {
+					if (child->options & PROC_O_TYPE_WORKER) {
+						ha_warning("A worker process unexpectedly died and this can only be explained by a bug in haproxy or its dependencies.\nPlease check that you are running an up to date and maintained version of haproxy and open a bug report.\n");
+						display_version();
+					}
+					if (!(global.tune.options & GTUNE_NOEXIT_ONFAILURE)) {
+						ha_alert("exit-on-failure: killing every processes with SIGTERM\n");
+						mworker_kill(SIGTERM);
+					}
 				}
 				/* 0 & SIGTERM (143) are normal, but we should report SIGINT (130) and other signals */
 				if (exitcode < 0 && status != 0 && status != 143)
@@ -680,10 +685,15 @@ static int cli_parse_reload(char **args, char *payload, struct appctx *appctx, v
 	struct stream *strm = NULL;
 	struct connection *conn = NULL;
 	int fd = -1;
+	int hardreload = 0;
 
 	if (!cli_has_level(appctx, ACCESS_LVL_OPER))
 		return 1;
 
+	/* hard reload requested */
+	if (*args[0] == 'h')
+		hardreload = 1;
+
 	/* This ask for a synchronous reload, which means we will keep this FD
 	   instead of closing it. */
 
@@ -699,7 +709,7 @@ static int cli_parse_reload(char **args, char *payload, struct appctx *appctx, v
 	if (fd != -1 && send_fd_uxst(proc_self->ipc_fd[0], fd) == 0) {
 		fd_delete(fd); /* avoid the leak of the FD after sending it via the socketpair */
 	}
-	mworker_reload();
+	mworker_reload(hardreload);
 
 	return 1;
 }
@@ -802,7 +812,8 @@ static struct cli_kw_list cli_kws = {{ },{
 	{ { "@!<pid>", NULL },         "@!<pid>                                 : send a command to the <pid> process", cli_parse_default, NULL, NULL, NULL, ACCESS_MASTER_ONLY},
 	{ { "@master", NULL },         "@master                                 : send a command to the master process", cli_parse_default, NULL, NULL, NULL, ACCESS_MASTER_ONLY},
 	{ { "show", "proc", NULL },    "show proc                               : show processes status", cli_parse_default, cli_io_handler_show_proc, NULL, NULL, ACCESS_MASTER_ONLY},
-	{ { "reload", NULL },          "reload                                  : reload haproxy", cli_parse_reload, NULL, NULL, NULL, ACCESS_MASTER_ONLY},
+	{ { "reload", NULL },          "reload                                  : achieve a soft-reload (-sf) of haproxy", cli_parse_reload, NULL, NULL, NULL, ACCESS_MASTER_ONLY},
+	{ { "hard-reload", NULL },     "hard-reload                             : achieve a hard-reload (-st) of haproxy", cli_parse_reload, NULL, NULL, NULL, ACCESS_MASTER_ONLY},
 	{ { "_loadstatus", NULL },     NULL,                                                             cli_parse_default, cli_io_handler_show_loadstatus, NULL, NULL, ACCESS_MASTER_ONLY},
 	{{},}
 }};
